@@ -1,14 +1,16 @@
-import os
+import os 
 import requests
-import logging
+import eon_logger.logging as log
+
+
+cls = log.Logger('fms', 'info')
+_logger = cls.create_logger()
 
-logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
 
 class FilesManager():
     def __init__(self, config):
-        print(config)
-        self.fms_host = config['FMS_HOST']
-        self.fms_port = config['FMS_PORT']
+        self.fms_host = config['FMS_HOST'] or '10.1.0.5'
+        self.fms_port = config['FMS_PORT'] or '8007'
         self.fms_url = f"{self.fms_host}:{self.fms_port}"
         self.base_location = os.getcwd()
         
@@ -22,7 +24,6 @@ class FilesManager():
                 for chunk in response.iter_content(chunk_size=1024): 
                     file.write(chunk)
             response.close()
-        logging.warning(f"File Downloaded Successfully {file_key}.{ext}")
         return f"File Donwloaded Successfully {file_key}.{ext}"
 
     def upload_file(self, file_key, ext, location, group, created_by):
@@ -35,11 +36,10 @@ class FilesManager():
             with file_request.post(url, file, headers=headers, stream=True) as req:
                 req.raise_for_status()
         file_request.close()
-        logging.warning(f"File Uploaded Successfully {file_key}.{ext}")
         return f"File Uploaded Successfully {file_key}.{ext}"
+        
 
     def delete_file(self, file_key, ext, location): 
         os.remove(os.path.join(self.base_location, f"{location}/{file_key}.{ext}"))
-        logging.warning(f"File Deleted Successfully {file_key}.{ext}")
         return f"File Deleted Successfully {file_key}.{ext}"
 
