@@ -2,19 +2,8 @@ import json
 import pika
 import pika.exceptions
 import time
-import os
-import logging
-import configparser
-
-
-
-
-logging.basicConfig(level=logging.WARNING, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
-logging.getLogger("pika").setLevel(logging.ERROR)
 
 class consumer_class(): 
-
-
     def __init__(self, service_name, handler, config):
         self.rabbit_user = config['RABBIT_USER']
         self.rabbit_password = config['RABBIT_PASSWORD']
